@@ -5,8 +5,9 @@ from pathlib import Path
 
 import pandas as pd
 import structlog
-from openstef.data_classes.prediction_job import PredictionJobDataClass
 
+from openstef.data_classes.prediction_job import PredictionJobDataClass
+from openstef.exceptions import NoRealisedLoadError
 from openstef.feature_engineering.feature_applicator import (
     OperationalPredictFeatureApplicator,
 )
@@ -67,13 +68,17 @@ def create_basecase_forecast_pipeline(
     # Make basecase forecast
     basecase_forecast = BaseCaseModel().predict(forecast_input)
 
+    # Check if input data is available
+    if len(basecase_forecast) == 0:
+        raise NoRealisedLoadError(pj["id"])
+
     # Estimate the stdev by using the stdev of the hour for historic (T-14d) load
     model.standard_deviation = generate_basecase_confidence_interval(forecast_input)
     logger.info("Postprocessing basecase forecast")
     # Apply confidence interval
     basecase_forecast = ConfidenceIntervalApplicator(
         model, forecast_input
-    ).add_confidence_interval(basecase_forecast, pj, quantile_confidence_interval=False)
+    ).add_confidence_interval(basecase_forecast, pj)
 
     # Add basecase for the component forecasts
     basecase_forecast = add_components_base_case_forecast(basecase_forecast)
