@@ -6,6 +6,8 @@ from typing import Any, List, Tuple
 import optuna
 import pandas as pd
 import structlog
+import os
+from pathlib import Path
 
 from openstef.data_classes.model_specifications import ModelSpecificationDataClass
 from openstef.data_classes.prediction_job import PredictionJobDataClass
@@ -87,7 +89,8 @@ def optimize_hyperparameters_pipeline(
         trial_number=best_trial_number,
     )
     if artifact_folder:
-        Reporter.write_report_to_disk(report=report, artifact_folder=artifact_folder)
+        report_folder = os.path.join(artifact_folder, str(pj["id"]))
+        Reporter.write_report_to_disk(report=report, report_folder=report_folder)
     return best_params
 
 
